/**
 * Document: MaxCompiler Training (maxcompiler-training.pdf)
 * Chapter: 1      Exercise: 2      Name: Gamma
 * MaxFile name: Gamma
 * Summary:
 * 	   Applies gamma correction to an image by calculating a lookup
 *     table for the gamma correction function and loading it into a
 *     mapped ROM in the Kernel.
 */
#include <math.h>
#include <stdio.h>
#include <stdlib.h>

#include "Maxfiles.h"
#include <MaxSLiCInterface.h>

#include "ppmIO.h"

uint64_t * generateGammaLUT()
{
	uint64_t *gammaRom = malloc(256 * sizeof(uint64_t));

	float gamma = 2.2;
	for (int i = 0; i < 256; i++) {
		float gammaVal = 255.0 * pow(i / 255.0, 1.0 / gamma);
		gammaRom[i] = gammaVal > 255 ? 255 : (uint32_t) gammaVal;
	}

	return gammaRom;
}

int main(void)
{
	printf("Loading image.\n");
	int width = 0, height = 0;
	int32_t *inImage;
	loadImage("lena.ppm", &inImage, &width, &height, 1);

	int dataSize = width * height * sizeof(int);
	// Allocate a buffer for the output image
	int *outImage = malloc(dataSize);

	printf("Generating gamma lookup table.\n");
	uint64_t *gammaRom = generateGammaLUT();

	printf("Running Kernel.\n");
	Gamma(width * height, inImage, outImage);

	printf("Saving image.\n");
	writeImage("lena_gamma.ppm", outImage, width, height, 1);

	printf("Exiting\n");
	return 0;
}
